import { LazyIterator } from './iterators/lazy_iterator';
import { DataElement, DatasetContainer } from './types';
export declare abstract class Dataset<T extends DataElement> {
    abstract iterator(): Promise<LazyIterator<T>>;
    filter(filterer: (value: T) => boolean): Dataset<T>;
    map<O extends DataElement>(transform: (value: T) => O): Dataset<O>;
    mapAsync<O extends DataElement>(transform: (value: T) => Promise<O>): Dataset<O>;
    batch(batchSize: number, smallLastBatch?: boolean): Dataset<DataElement>;
    concatenate(dataset: Dataset<T>): Dataset<T>;
    repeat(count?: number): Dataset<T>;
    take(count: number): Dataset<T>;
    skip(count: number): Dataset<T>;
    shuffle(bufferSize: number, seed?: string, reshuffleEachIteration?: boolean): Dataset<T>;
    prefetch(bufferSize: number): Dataset<T>;
    collectAll(): Promise<T[]>;
    forEach(f: (input: T) => void): Promise<void>;
}
export declare function datasetFromIteratorFn<T extends DataElement>(iteratorFn: () => Promise<LazyIterator<T>>): Dataset<T>;
export declare function array<T extends DataElement>(items: T[]): Dataset<T>;
export declare function zip<O extends DataElement>(datasets: DatasetContainer): Dataset<O>;
